@@ -24,6 +24,7 @@
 #include "echonest_export.h"
 #include "TypeInformation.h"
 #include "Song.h"
+#include "CommonTypes.h"
 
 #include <QDebug>
 #include <QSharedData>
@@ -37,9 +38,6 @@ namespace Echonest{
     class Biography;
     class Catalog;
 
-    class Artist;
-    typedef QVector< Artist > Artists;
-
     /**
      * This encapsulates an Echo Nest artist---it always holds the basic info of artist id and
      *  artist name, and can be queried for more data.
@@ -120,6 +118,7 @@ namespace Echonest{
          */
 
         /**
+         * @Deprecated
          * A list of audio files on the web for this artist.
          */
         AudioList audio() const;
@@ -179,6 +178,12 @@ namespace Echonest{
         TermList terms() const;
         void setTerms( const TermList& );
 
+        /**
+         * Genres describing this artist.
+         */
+        Genres genres() const;
+        void setGenres( const Genres& );
+
         /**
          * Urls pointing to this artists' basic information around the web.
          */
@@ -208,6 +213,7 @@ namespace Echonest{
         void setForeignIds( const ForeignIds& ids );
 
         /**
+         * @Deprecated
          * Fetch a list of audio documents found on the web that are related to this artist.
          *
          * @param numResults Limit how many results are returned
@@ -342,6 +348,7 @@ namespace Echonest{
         static QNetworkReply* listTerms( const QString& type = QLatin1String("style") );
 
         /**
+         * @Deprecated
          * Fetch a list of genres supported by echonest
          */
         static QNetworkReply* fetchGenres();
@@ -380,6 +387,7 @@ namespace Echonest{
         static QVector< QString > parseTermList( QNetworkReply* ) throw( ParseError );
 
         /**
+         * @Deprecated
          * Parse the result of a genres query. Returns the list of genres delivered.
          */
         static QVector< QString > parseGenreList( QNetworkReply* ) throw ( ParseError );
@@ -393,6 +401,7 @@ namespace Echonest{
         QSharedDataPointer<ArtistData> d;
 
         friend class Catalog;
+        friend class Genre;
     };
 
     ECHONEST_EXPORT QDebug operator<<(QDebug d, const Echonest::Artist& artist);
@@ -400,5 +409,6 @@ namespace Echonest{
 } // namespace
 
 Q_DECLARE_METATYPE( Echonest::Artist )
+Q_DECLARE_METATYPE( Echonest::Artists );
 
 #endif
