@@ -31,50 +31,6 @@ void ArtistTest::initTestCase()
     Config::instance()->setAPIKey( "JGJCRKWLXLBZIFAZB" );
 }
 
-void ArtistTest::testAudioUrl()
-{
-    Artist testArtist;
-    testArtist.setName( QLatin1String( "FooArtist" ) );
-
-    QNetworkReply* reply = testArtist.fetchAudio();
-
-    QVERIFY( reply->url().toString() == QLatin1String( "http://developer.echonest.com/api/v4/artist/audio?api_key=JGJCRKWLXLBZIFAZB&format=xml&name=FooArtist" ) );
-
-    reply = testArtist.fetchAudio( 15 );
-    QVERIFY( reply->url().toString() == QLatin1String( "http://developer.echonest.com/api/v4/artist/audio?api_key=JGJCRKWLXLBZIFAZB&format=xml&name=FooArtist&results=15" ) );
-
-    reply = testArtist.fetchAudio( 15, 5 );
-    QVERIFY( reply->url().toString() == QLatin1String( "http://developer.echonest.com/api/v4/artist/audio?api_key=JGJCRKWLXLBZIFAZB&format=xml&name=FooArtist&results=15&start=5" ) );
-
-    testArtist.setName( QString() );
-    testArtist.setId( "ARH6W4X1187B99274F" );
-    reply = testArtist.fetchAudio( 15, -1 );
-    QVERIFY( reply->url().toString() == QLatin1String( "http://developer.echonest.com/api/v4/artist/audio?api_key=JGJCRKWLXLBZIFAZB&format=xml&id=ARH6W4X1187B99274F&results=15" ) );
-
-    testArtist.setName( QLatin1String( "FooArtist" ) );
-    reply = testArtist.fetchAudio( 100 );
-    QVERIFY( reply->url().toString() == QLatin1String( "http://developer.echonest.com/api/v4/artist/audio?api_key=JGJCRKWLXLBZIFAZB&format=xml&id=ARH6W4X1187B99274F&results=100" ) );
-}
-
-void ArtistTest::testAudio()
-{
-    Artist testArtist;
-    testArtist.setName( QLatin1String( "Goo Goo Dolls") );
-
-    QNetworkReply* reply = testArtist.fetchAudio( 5, 2 );
-    qDebug() << reply->url().toString();
-    QEventLoop loop;
-    loop.connect( reply, SIGNAL(finished()), SLOT(quit()) );
-    loop.exec();
-    testArtist.parseProfile( reply );
-
-    qDebug() << testArtist.audio().size();
-    QVERIFY( testArtist.audio().size() == 2 );
-
-    qDebug() << testArtist.audio().at(0).artist() << testArtist.audio().at(0).date() << testArtist.audio().at(0).id() << testArtist.audio().at(0).length() << testArtist.audio().at(0).release() <<
-                testArtist.audio().at(0).title() << testArtist.audio().at(0).url() << testArtist.audio().at(0).title() << testArtist.audio().at(0).link();
-}
-
 void ArtistTest::testBiographiesUrl()
 {
     Artist testArtist;
@@ -283,8 +239,8 @@ void ArtistTest::testProfileUrl()
     Artist testArtist;
     testArtist.setName( QLatin1String( "ReallyGoodArtist" ) );
 
-    QNetworkReply* reply = testArtist.fetchProfile( ArtistInformation( ArtistInformation::Familiarity | ArtistInformation::Videos | ArtistInformation::Audio ) );
-    QVERIFY( reply->url().toString() == QLatin1String( "http://developer.echonest.com/api/v4/artist/profile?api_key=JGJCRKWLXLBZIFAZB&format=xml&name=ReallyGoodArtist&bucket=audio&bucket=familiarity&bucket=video" ) );
+    QNetworkReply* reply = testArtist.fetchProfile( ArtistInformation( ArtistInformation::Familiarity | ArtistInformation::Videos  ) );
+    QVERIFY( reply->url().toString() == QLatin1String( "http://developer.echonest.com/api/v4/artist/profile?api_key=JGJCRKWLXLBZIFAZB&format=xml&name=ReallyGoodArtist&bucket=familiarity&bucket=video" ) );
 
     ArtistInformation info( ArtistInformation::Biographies | ArtistInformation::News | ArtistInformation::Reviews | ArtistInformation::Terms | ArtistInformation::Urls );
     info.setIdSpaces( QStringList() << QLatin1String( "musicbrainz" ) );
@@ -304,7 +260,7 @@ void ArtistTest::testProfile()
     Artist testArtist;
     testArtist.setName( QLatin1String( "The American Dollar" ) );
 
-    QNetworkReply* reply = testArtist.fetchProfile( ArtistInformation( ArtistInformation::Audio | ArtistInformation::Hotttnesss | ArtistInformation::Familiarity | ArtistInformation::Videos ) );
+    QNetworkReply* reply = testArtist.fetchProfile( ArtistInformation( ArtistInformation::Hotttnesss | ArtistInformation::Familiarity | ArtistInformation::Videos ) );
     QEventLoop loop;
     loop.connect( reply, SIGNAL(finished()), SLOT(quit()) );
     loop.exec();
@@ -360,7 +316,7 @@ void ArtistTest::testSearchUrl()
     params.append( Artist::SearchParamEntry( Artist::Description, QLatin1String( "alternative rock" ) ) );
     params.append( Artist::SearchParamEntry( Artist::FuzzyMatch, true ) );
     searchResult = Artist::search( params, ArtistInformation( ArtistInformation::Audio | ArtistInformation::Videos ), true );
-    QCOMPARE( searchResult->url().toString(), QLatin1String( "http://developer.echonest.com/api/v4/artist/search?api_key=JGJCRKWLXLBZIFAZB&format=xml&max_familiarity=12.221&min_hotttnesss=0.52&description=alternative+rock&fuzzy_match=true&limit=true&bucket=audio&bucket=video" ) );
+    QCOMPARE( searchResult->url().toString(), QLatin1String( "http://developer.echonest.com/api/v4/artist/search?api_key=JGJCRKWLXLBZIFAZB&format=xml&max_familiarity=12.221&min_hotttnesss=0.52&description=alternative+rock&fuzzy_match=true&limit=true&bucket=video" ) );
 
 
 }
@@ -368,9 +324,9 @@ void ArtistTest::testSearchUrl()
 void ArtistTest::testSearch()
 {
     Artist::SearchParams params;
-    params.append( Artist::SearchParamEntry( Artist::Description, QLatin1String( "emo^2" ) ) );
-    params.append( Artist::SearchParamEntry( Artist::Description, QLatin1String( "female vocalist^2" ) ) );
-    params.append( Artist::SearchParamEntry( Artist::Mood, QLatin1String( "happy^2" ) ) );
+    params.append( Artist::SearchParamEntry( Artist::Description, QLatin1String( "emo" ) ) );
+    params.append( Artist::SearchParamEntry( Artist::Description, QLatin1String( "female vocalist" ) ) );
+    params.append( Artist::SearchParamEntry( Artist::Mood, QLatin1String( "happy" ) ) );
     params.append( Artist::SearchParamEntry( Artist::FuzzyMatch, true ) );
     QNetworkReply* searchResult = Artist::search( params, ArtistInformation( ArtistInformation::Familiarity | ArtistInformation::Hotttnesss ) );
 
@@ -396,7 +352,7 @@ void ArtistTest::testSearch()
     params.append( Artist::SearchParamEntry( Artist::Description, QLatin1String( "alternative rock" ) ) );
     params.append( Artist::SearchParamEntry( Artist::Description, QLatin1String( "stadium rock" ) ) );
     params.append( Artist::SearchParamEntry( Artist::FuzzyMatch, true ) );
-    searchResult = Artist::search( params, ArtistInformation( ArtistInformation::Familiarity | ArtistInformation::Hotttnesss | ArtistInformation::News | ArtistInformation::Blogs | ArtistInformation::Audio ) );
+    searchResult = Artist::search( params, ArtistInformation( ArtistInformation::Familiarity | ArtistInformation::Hotttnesss | ArtistInformation::News | ArtistInformation::Blogs  ) );
     qDebug() << "Querying:" << searchResult->url().toString();
     QEventLoop loop2;
     loop2.connect( searchResult, SIGNAL(finished()), SLOT(quit()) );
@@ -463,10 +419,10 @@ void ArtistTest::testSimilarUrl()
     params.append( Artist::SearchParamEntry( Artist::Name, QLatin1String( "Queen" ) ) );
     params.append( Artist::SearchParamEntry( Artist::MinHotttnesss, 0.5 ) );
 
-    QNetworkReply* reply = Artist::fetchSimilar( params, ArtistInformation( ArtistInformation::Hotttnesss | ArtistInformation::Familiarity | ArtistInformation::Audio ) );
+    QNetworkReply* reply = Artist::fetchSimilar( params, ArtistInformation( ArtistInformation::Hotttnesss | ArtistInformation::Familiarity ) );
 
     qDebug() << reply->url().toString();
-    QVERIFY( reply->url().toString() == QLatin1String( "http://developer.echonest.com/api/v4/artist/similar?api_key=JGJCRKWLXLBZIFAZB&format=xml&bucket=audio&bucket=familiarity&bucket=hotttnesss&name=The+Beatles&name=Rilo+Kiley&name=Queen&min_hotttnesss=0.5" ) );
+    QVERIFY( reply->url().toString() == QLatin1String( "http://developer.echonest.com/api/v4/artist/similar?api_key=JGJCRKWLXLBZIFAZB&format=xml&bucket=familiarity&bucket=hotttnesss&name=The+Beatles&name=Rilo+Kiley&name=Queen&min_hotttnesss=0.5" ) );
 
     params.clear();
     params.append( Artist::SearchParamEntry( Artist::Name, QLatin1String( "Devo" ) ) );
@@ -474,9 +430,9 @@ void ArtistTest::testSimilarUrl()
     params.append( Artist::SearchParamEntry( Artist::Name, QLatin1String( "Lady Gaga" ) ) );
     params.append( Artist::SearchParamEntry( Artist::MinFamiliarity, 0.5 ) );
 
-    reply = Artist::fetchSimilar( params, ArtistInformation( ArtistInformation::Biographies | ArtistInformation::News | ArtistInformation::Audio ), 10 );
+    reply = Artist::fetchSimilar( params, ArtistInformation( ArtistInformation::Biographies | ArtistInformation::News  ), 10 );
 
-    QVERIFY( reply->url().toString() == QLatin1String( "http://developer.echonest.com/api/v4/artist/similar?api_key=JGJCRKWLXLBZIFAZB&format=xml&bucket=audio&bucket=biographies&bucket=news&results=10&name=Devo&name=The+New+Pornographers&name=Lady+Gaga&min_familiarity=0.5" ) );
+    QVERIFY( reply->url().toString() == QLatin1String( "http://developer.echonest.com/api/v4/artist/similar?api_key=JGJCRKWLXLBZIFAZB&format=xml&bucket=biographies&bucket=news&results=10&name=Devo&name=The+New+Pornographers&name=Lady+Gaga&min_familiarity=0.5" ) );
 }
 
 void ArtistTest::testSimilar()
@@ -487,7 +443,7 @@ void ArtistTest::testSimilar()
     params.append( Artist::SearchParamEntry( Artist::Name, QLatin1String( "Queen" ) ) );
     params.append( Artist::SearchParamEntry( Artist::MinHotttnesss, 0.5 ) );
 
-    QNetworkReply* reply = Artist::fetchSimilar( params, ArtistInformation( ArtistInformation::Hotttnesss | ArtistInformation::Familiarity | ArtistInformation::Audio ) );
+    QNetworkReply* reply = Artist::fetchSimilar( params, ArtistInformation( ArtistInformation::Hotttnesss | ArtistInformation::Familiarity  ) );
 
     QEventLoop loop;
     loop.connect( reply, SIGNAL(finished()), SLOT(quit()) );
@@ -500,7 +456,6 @@ void ArtistTest::testSimilar()
     Q_FOREACH( const Artist& artist, artists ) {
         QVERIFY( artist.familiarity() >= 0 );
         QVERIFY( artist.hotttnesss() >= 0 );
-        QVERIFY( artist.audio().size() > 0 );
     }
 
     artists.clear();
@@ -668,7 +623,7 @@ void ArtistTest::testSuggest()
 
     artists = Artist::parseSuggest( reply );
     qDebug() << "Got suggestions:" << artists;
-    QCOMPARE( artists.size(), 0 );
+    QCOMPARE( artists.size(), 1 );
 
     reply = Artist::suggest( QLatin1String( "tallest mangggggg" ), 12 );
     QCOMPARE( reply->url().toString(), QLatin1String( "http://developer.echonest.com/api/v4/artist/suggest?api_key=JGJCRKWLXLBZIFAZB&format=xml&name=tallest+mangggggg&results=12" ) );
@@ -758,10 +713,7 @@ void ArtistTest::testUrls()
     testArtist.parseProfile( reply );
 
     QVERIFY( !testArtist.lastFmUrl().isEmpty() );
-    QVERIFY( !testArtist.aolMusicUrl().isEmpty() );
     QVERIFY( !testArtist.myspaceUrl().isEmpty() );
-    QVERIFY( !testArtist.amazonUrl().isEmpty() );
-    QVERIFY( !testArtist.itunesUrl().isEmpty() );
     QVERIFY( !testArtist.musicbrainzUrl().isEmpty() );
 }
 
@@ -805,16 +757,23 @@ void ArtistTest::testVideos()
     qDebug() << testArtist.videos();
 }
 
-void ArtistTest::testGenres()
+void ArtistTest::testUrlsFix()
 {
-    QNetworkReply* reply = Artist::fetchGenres();
+    Artist::SearchParams params;
+    params.append( Artist::SearchParamEntry( Artist::Name, QLatin1String( "The Beatles" ) ) );
+
+    QNetworkReply* reply = Artist::fetchSimilar( params, ArtistInformation( ArtistInformation::Urls ) );
+
     QEventLoop loop;
     loop.connect( reply, SIGNAL(finished()), SLOT(quit()) );
     loop.exec();
+    Echonest::Artists artists = Echonest::Artist::parseSimilar( reply );
 
-    QVector< QString > genres = Artist::parseGenreList( reply );
-    QVERIFY( genres.size() > 0 );
-    QVERIFY( genres.contains( QLatin1String( "dub" ) ) );
+    QVERIFY( artists.size() > 0 );
+    Q_FOREACH( const Artist& artist, artists ) {
+        QVERIFY( !artist.lastFmUrl().isEmpty() );
+        QVERIFY( !artist.musicbrainzUrl().isEmpty() );
+    }
 }
 
 QTEST_MAIN(ArtistTest)
